from setuptools import setup

setup(name='Distribution_Ritika',
      version='0.17',
      description='Gaussian and Binomial distributions',
      packages=['Distribution_Ritika'],
      author='Ritika_Gupta',
      zip_safe=False)
